@@ -1,5 +1,3 @@
-{-# OPTIONS_GHC -fno-warn-orphans #-}
-
 module Test.Framework.Runners.Console (
         defaultMain, defaultMainWithArgs, defaultMainWithOpts,
         SuppliedRunnerOptions, optionsDescription,
@@ -23,16 +21,11 @@ import System.Environment
 import System.Exit
 import System.IO
 
+#if !MIN_VERSION_base(4,8,0)
 import Data.Monoid
-
-#if !MIN_VERSION_base(4,7,0)
-instance Functor OptDescr where
-    fmap f (Option a b arg_descr c) = Option a b (fmap f arg_descr) c
-
-instance Functor ArgDescr where
-    fmap f (NoArg a) = NoArg (f a)
-    fmap f (ReqArg g s) = ReqArg (f . g) s
-    fmap f (OptArg g s) = OptArg (f . g) s
+#endif
+#if !(MIN_VERSION_base(4,7,0))
+import Data.Orphans ()
 #endif
 
 -- | @Nothing@ signifies that usage information should be displayed.
